Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/cc_liquid/__init__.py | 7 | 0 | 0 | 100%
src/cc_liquid/backtester.py | 383 | 179 | 0 | 53%
src/cc_liquid/callbacks.py | 97 | 47 | 34 | 52%
src/cc_liquid/cli.py | 540 | 540 | 0 | 0%
src/cc_liquid/cli_callbacks.py | 51 | 51 | 0 | 0%
src/cc_liquid/cli_display.py | 890 | 890 | 4 | 0%
src/cc_liquid/completion.py | 85 | 85 | 0 | 0%
src/cc_liquid/config.py | 200 | 93 | 0 | 54%
src/cc_liquid/data_loader.py | 58 | 12 | 0 | 79%
src/cc_liquid/order.py | 123 | 11 | 0 | 91%
src/cc_liquid/portfolio/__init__.py | 2 | 0 | 0 | 100%
src/cc_liquid/portfolio/sizing.py | 34 | 3 | 0 | 91%
src/cc_liquid/stop_loss.py | 152 | 69 | 0 | 55%
src/cc_liquid/trader.py | 554 | 458 | 0 | 17%
Total | 3176 | 2438 | 38 | 23%

No items found using the specified filter.